@@ -112,463 +112,20 @@ class Alphabets:
 alphabets = Alphabets()
 
 
-@dataclass
-class Sequence:
-    """Container for a single biological sequence
-
-    Examples:
-        >>> s1 = Sequence('test_dna', 'ACGATCGACTAGCA')
-        >>> s1
-        Sequence(header='test_dna', sequence='ACGATCGACTAGCA', \
-alphabet=Alphabet(name='DNA', members='-?ACGNT'))
-        >>> s2 = Sequence('test_aa', 'QAPISAIWPOIWQ*')
-        >>> s2
-        Sequence(header='test_aa', sequence='QAPISAIWPOIWQ*', \
-alphabet=Alphabet(name='AminoAcid', members='*-?ACDEFGHIKLMNPQRSTVWXY'))
-
-    Returns:
-        [type]: [description]
-    """
-    header: str = None
-    sequence: str = None
-    alphabet: Alphabet = None
-
-    def __post_init__(self):
-        if self.alphabet is not None:
-            return
-        if self.sequence is None:
-            self.alphabet = alphabets.DNA
-        else:
-            self.alphabet = sorted(
-                alphabets,
-                key=lambda alphabet: alphabet.score(self.sequence)
-            ).pop()
-
-    def to_dict(self) -> Dict[str, str]:
-        """Make dictionary with header and sequence elements
-
-        Returns:
-            Dict[str, str]: sequence dictionary
-        """
-        return dict(
-            header=self.header,
-            sequence=self.sequence
-        )
-
-    @classmethod
-    def from_fasta(cls, string: str) -> 'Sequence':
-        """Create a sequence object from a fasta formatted file. _single sequence only_
-
-        Examples:
-            >>> fasta_string = '>test\\nACGT'
-            >>> Sequence.from_fasta(fasta_string)
-            Sequence(header='test', sequence='ACGT', \
-alphabet=Alphabet(name='DNA', members='-?ACGNT'))
-
-        Arguments:
-            string (str)
-
-        Returns:
-            Sequence
-        """
-        lines = string.strip().split('\n')
-        header = lines[0][1:]
-        sequence = ''.join(lines[1:])
-        return cls(header, sequence)
-
-    def to_fasta(self) -> str:
-        """Make fasta formatted sequence entry
-
-        Returns:
-            str: sequence in fasta format
-        """
-        return f'>{self.header}\n{self.sequence}'
-
-
-class SequenceReader:
-    def __init__(
-        self,
-        string: str = None,
-        filename: str = None,
-        filetype: str = None
-    ) -> None:
-        """Iterator over fasta/json formatted sequence strings
-
-        Args:
-            string (str): fasta/json formatted string
-            filename (str): fasta/json file name
-            filetype (str): fasta or json
-
-        Examples:
-            >>> fasta_string = '>1\\nACGC\\n>2\\nTGTGTA\\n'
-            >>> fasta_reader = SequenceReader(string=fasta_string, \
-filetype='fasta')
-            >>> next(fasta_reader)
-            Sequence(header='1', sequence='ACGC', \
-alphabet=Alphabet(name='DNA', members='-?ACGNT'))
-        """
-        assert bool(string) ^ bool(filename), \
-            'Must specify exactly one of string or filename'  # exclusive OR
-        if filename:
-            with open(filename, 'r') as filehandle:
-                string = filehandle.read().strip()
-
-        self.string = string
-
-        if filetype == 'fasta':
-            self._iter = self._fasta_iter
-        elif filetype == 'json':
-            self._iter = self._json_iter
-        else:
-            raise ValueError(f'filetype "{filetype}" is not supported')
-
-    def __iter__(self) -> Iterable[Sequence]:
-        """Iterate over header,sequence tuples
-
-        Returns:
-            Iterable[Sequence]: [description]
-
-        Yields:
-            Iterable[Sequence]: [description]
-        """
-        yield from self._iter()
-
-    def __next__(self) -> Sequence:
-        """Next header and sequence in the iterator
-
-        Returns:
-            Tuple[str, str]: [description]
-        """
-        return next(self._iter())
-
-    def _fasta_iter(self) -> Iterable[Sequence]:
-        fasta_iter = (
-            x for _, x in groupby(
-                self.string.strip().split('\n'),
-                lambda line: line[:1] == '>'
-            )
-        )
-        for header in fasta_iter:
-            header = next(header)[1:].strip()
-            seq = ''.join(s.strip() for s in next(fasta_iter))
-            yield Sequence(header, seq)
-
-    def _json_iter(self) -> Iterable[Sequence]:
-        for entry in json.loads(self.string):
-            yield Sequence(entry['header'], entry['sequence'])
-
-
-class SequenceCollection(metaclass=ABCMeta):
-    """
-    (Partially) Abstract Base Class for sequence collections.
-    Classes extending from this baseclass should override
-    `__setitem__`, `__getitem__`, `__delitem__`, `headers`, and `n_seqs`.
-
-    If the above methods are implemented, this automatically enables the
-    following methods: `from_fasta`, `to_fasta`, `from_json`, `to_json`.
-
-    Args:
-        sequences (Optional[Iterable[Tuple[str, str]]], optional):
-            Iterable of (header, sequence) tuples. Defaults to None.
-        sequence_annotation (Optional[SequenceAnnotation]):
-                picea SequenceAnnotation object. Defaults to None.
-
-    Raises:
-        NotImplementedError: Abstract Base Class can not be initialized
-            and serves as a template only
-    """
-    @abstractmethod
-    def __init__(
-        self,
-        sequences: Optional[Iterable[Sequence]] = None,
-        sequence_annotation: Optional['SequenceAnnotation'] = None
-    ) -> None:
-        raise NotImplementedError('Not implemented in base class')
-
-    @abstractmethod
-    def __setitem__(self, header: str, seq: str) -> None:
-        raise NotImplementedError()
-
-    @abstractmethod
-    def __getitem__(self, header: str) -> Sequence:
-        raise NotImplementedError()
-
-    @abstractmethod
-    def __delitem__(self, header: str) -> None:
-        raise NotImplementedError()
-
-    def __iter__(self) -> Iterable[Sequence]:
-        for header in self.headers:
-            yield self[header]
-
-    def __next__(self) -> Sequence:
-        header = next(self.headers)
-        return self[header]
-
-    @abstractproperty
-    def headers(self) -> List[str]:
-        """List of sequences headers.
-        Overridden in subclasses.
-
-        Raises:
-            NotImplementedError
-
-        Returns:
-            List[str]: List of sequence headers
-        """
-        raise NotImplementedError()
-
-    @property
-    def sequences(self) -> List[str]:
-        """List of sequences without headers
-
-        Returns:
-            List[str]: list of sequences
-        """
-        return [self[header] for header in self.headers]
-
-    @abstractproperty
-    def n_seqs(self) -> int:
-        """Return the number of sequences in the collection.
-        Overridden in subclasses
-
-        Raises:
-            NotImplementedError
-
-        Returns:
-            int: number of sequences
-        """
-        raise NotImplementedError()
-
-    @classmethod
-    def from_fasta(
-        cls,
-        filename: str = None,
-        string: str = None,
-    ) -> 'SequenceCollection':
-        """Parse a fasta formatted string into a SequenceCollection object
-
-        Keyword Arguments:
-            filename {String} -- filename string (default: {None})
-            string {String} -- fasta formatted string (default: {None})
-
-        Returns:
-            SequenceCollection -- SequenceCollection instance
-        """
-        sequencecollection = cls()
-
-        for seq in SequenceReader(
-            string=string, filename=filename, filetype='fasta'
-        ):
-            sequencecollection[seq.header] = seq.sequence
-        return sequencecollection
-
-    def to_fasta(self) -> str:
-        """Get a fasta-formatted string of the sequence collection
-
-        Returns:
-            str: Multi-line fasta-formatted string
-        """
-        return '\n'.join([seq.to_fasta() for seq in self])
-
-    @classmethod
-    def from_json(
-        cls,
-        filename: Optional[str] = None,
-        string: Optional[str] = None
-    ) -> 'SequenceCollection':
-        """[summary]
-
-        Keyword Arguments:
-            string {String} -- JSON formatted string
-
-        Returns:
-            SequenceCollection -- SequenceCollection instance
-        """
-        sequencecollection = cls()
-
-        for seq in SequenceReader(
-            string=string, filename=filename, filetype='json'
-        ):
-            sequencecollection[seq.header] = seq.sequence
-
-        return sequencecollection
-
-    def to_json(self, indent: Optional[int] = None) -> str:
-        """[summary]
-
-        Returns:
-            str: [description]
-        """
-        gene_dicts = [seq.to_dict() for seq in self]
-        return json.dumps(gene_dicts, indent=indent)
-
-
-class SequenceList(SequenceCollection):
-    """
-    A container for multiple (unaligned) DNA or amino acid sequences
-    """
-    def __init__(
-        self: 'SequenceCollection',
-        sequences: Iterable[Tuple[str, str]] = None,
-        sequence_annotation: 'SequenceAnnotation' = None
-    ):
-        self._collection = dict()
-        if sequences:
-            for header, sequence in sequences:
-                self[header] = sequence
-        self.sequence_annotation = sequence_annotation
-
-    def __setitem__(self, header: str, seq: str) -> None:
-        if header in self.headers:
-            warn(f'Turning duplicate header "{header}" into unique header')
-            new_header = header
-            modifier = 0
-            while new_header in self.headers:
-                modifier += 1
-                new_header = f'{header}_{modifier}'
-            header = new_header
-        self._collection[header] = seq
-
-    def __getitem__(self, header: str) -> Sequence:
-        sequence = self._collection[header]
-        return Sequence(header, sequence)
-
-    def __delitem__(self, header: str) -> None:
-        del self._collection[header]
-
-    @property
-    def headers(self) -> List[str]:
-        return list(self._collection.keys())
-
-    @property
-    def n_seqs(self) -> int:
-        return len(self._collection.keys())
-
-    def align(
-        self,
-        method: str = 'mafft',
-        method_kwargs: Dict[str, str] = dict()
-    ):
-        """[summary]
-
-        Args:
-            method (str, optional): [description]. Defaults to 'mafft'.
-            method_kwargs (Dict[str, str], optional): [description]. \
-                Defaults to dict().
-
-        Returns:
-            [type]: [description]
-        """
-        fasta = self.to_fasta()
-        command = [method, *chain(*method_kwargs.items()), '-']
-        process = Popen(
-            command,
-            stdin=PIPE,
-            stdout=PIPE,
-            stderr=PIPE
-        )
-        stdout, stderr = process.communicate(input=fasta.encode())
-        aligned_fasta = stdout.decode().strip()
-        return MultipleSequenceAlignment.from_fasta(string=aligned_fasta)
-
-
-class MultipleSequenceAlignment(SequenceCollection):
-    def __init__(
-        self,
-        sequences: Optional[Iterable[Sequence]] = None,
-        sequence_annotation: Optional['SequenceAnnotation'] = None
-    ) -> None:
-        """
-        A container for multiple aligned DNA or amino acid sequences
-        """
-        self._collection = np.empty((0, 0), dtype='uint8')
-        self._header_idx = dict()
-        if sequences:
-            for seq in sequences:
-                self[seq.header] = seq.sequence
-        if sequence_annotation:
-            sequence_annotation.sequence_collection = self
-        self.sequence_annotation = sequence_annotation
-
-    def __setitem__(self, header: str, seq: str) -> None:
-        seq = seq.encode()
-        if header in self._header_idx:
-            warn(f'Turning duplicate header "{header}" into unique header')
-            new_header = header
-            modifier = 0
-            while new_header in self._header_idx:
-                modifier += 1
-                new_header = f'{header}_{modifier}'
-            header = new_header
-        n_seq, n_char = self._collection.shape
-        if n_seq == 0:
-            self._collection = np.array([[*seq]], dtype='uint8')
-        else:
-            len_diff = len(seq) - n_char
-
-            filler1 = np.array([[*b'-'] * len_diff], dtype='uint8')
-            arr = np.hstack((
-                self._collection,
-                np.repeat(filler1, n_seq, axis=0)
-            ))
-
-            filler2 = np.array([*b'-'] * -len_diff, dtype='uint8')
-            new_row = np.array([[*seq, *filler2]], dtype='uint8')
-
-            arr = np.vstack((arr, new_row))
-            self._collection = arr
-        self._header_idx[header] = n_seq
-
-    def __getitem__(self, header: str) -> Sequence:
-        idx = self._header_idx[header]
-        n_chars = self._collection.shape[1]
-        sequence = self._collection[idx] \
-            .view(f'S{n_chars}')[0] \
-            .decode()
-        return Sequence(header, sequence)
-
-    def __delitem__(self, header: str) -> None:
-        """WIP!
-
-        Args:
-            header (str): [description]
-        """
-        idx = self._header_idx[header]
-        self._collection = np.delete(self._collection, idx, axis=0)
-        # del
-
-    @property
-    def headers(self) -> List[str]:
-        return list(self._header_idx.keys())
-
-    @property
-    def n_seqs(self) -> int:
-        return self._collection.shape[0]
-
-    @property
-    def n_chars(self) -> int:
-        return self._collection.shape[1]
-
-    @property
-    def shape(self) -> int:
-        return self._collection.shape
-
-
 class SequenceAnnotation:
     def __init__(
         self,
-        sequence_collection: Optional['SequenceCollection'] = None
+        sequence: Optional['Sequence'] = None
     ) -> None:
         """[summary]
 
         Args:
-            sequence_collection (Optional['SequenceCollection']): \
-                [description]. Defaults to None.
+            sequence (Optional[Sequence], optional): [description]. Defaults\
+                 to None.
         """
-        if sequence_collection:
-            sequence_collection.sequence_annotation = self
-        self.sequence_collection = sequence_collection
+        if sequence:
+            sequence.annotation = self
+        self.sequence = sequence
         self._intervals = dict()
         self._gff_headers = list()
 
@@ -581,7 +138,10 @@ class SequenceAnnotation:
         self._intervals[key] = value
 
     def __iter__(self):
-        yield from self._intervals.values()
+        try:
+            yield from self._intervals.values()
+        except StopIteration:
+            return
 
     @property
     def intervals(self):
@@ -592,14 +152,14 @@ class SequenceAnnotation:
         cls,
         filename: Optional[str] = None,
         string: Optional[str] = None,
-        sequence_collection: Optional['SequenceCollection'] = None
+        sequence: Optional['Sequence'] = None
     ) -> 'SequenceAnnotation':
         """[summary]
 
         Args:
             filename ([type], optional): [description]. Defaults to None.
             string ([type], optional): [description]. Defaults to None.
-            sequence_collection ([type], optional): [description].
+            sequence ([type], optional): [description].
                 Defaults to None.
 
         Returns:
@@ -607,7 +167,7 @@ class SequenceAnnotation:
         """
         assert filename or string
         assert not (filename and string)
-        sequence_annotation = cls(sequence_collection=sequence_collection)
+        sequence_annotation = cls(sequence=sequence)
         header = True
         if filename:
             with open(filename) as filehandle:
@@ -656,7 +216,7 @@ class SequenceAnnotation:
         cls,
         filename: Optional[str] = None,
         string: Optional[str] = None,
-        sequence_collection: Optional['SequenceCollection'] = None
+        sequence: Optional['Sequence'] = None
     ) -> 'SequenceAnnotation':
         """[summary]
         """
@@ -666,7 +226,7 @@ class SequenceAnnotation:
             with open(filename) as filehandle:
                 string = filehandle.read()
 
-        sequence_annotation = cls(sequence_collection=sequence_collection)
+        sequence_annotation = cls(sequence=sequence)
 
         gene_dicts = json.loads(string)
         assert isinstance(gene_dicts, list)
@@ -966,6 +526,454 @@ class SequenceInterval:
             yield from child._get_children(_visited=_visited)
 
 
+@dataclass
+class Sequence:
+    """Container for a single biological sequence
+
+    Examples:
+        >>> s1 = Sequence('test_dna', 'ACGATCGACTAGCA')
+        >>> s1
+        Sequence(header='test_dna', sequence='ACGATCGACTAGCA', \
+alphabet=Alphabet(name='DNA', members='-?ACGNT'))
+        >>> s2 = Sequence('test_aa', 'QAPISAIWPOIWQ*')
+        >>> s2
+        Sequence(header='test_aa', sequence='QAPISAIWPOIWQ*', \
+alphabet=Alphabet(name='AminoAcid', members='*-?ACDEFGHIKLMNPQRSTVWXY'))
+
+    Returns:
+        [type]: [description]
+    """
+    header: str = None
+    sequence: str = None
+    alphabet: Alphabet = None
+    annotation: Optional[SequenceAnnotation] =\
+        field(default_factory=SequenceAnnotation, repr=False)
+
+    def __post_init__(self):
+        if self.alphabet is not None:
+            return
+        if self.sequence is None:
+            self.alphabet = alphabets.DNA
+        else:
+            self.alphabet = sorted(
+                alphabets,
+                key=lambda alphabet: alphabet.score(self.sequence)
+            ).pop()
+
+    def to_dict(self) -> Dict[str, str]:
+        """Make dictionary with header and sequence elements
+
+        Returns:
+            Dict[str, str]: sequence dictionary
+        """
+        return dict(
+            header=self.header,
+            sequence=self.sequence
+        )
+
+    @classmethod
+    def from_fasta(cls, string: str) -> 'Sequence':
+        """Create a sequence object from a fasta formatted file. _single sequence only_
+
+        Examples:
+            >>> fasta_string = '>test\\nACGT'
+            >>> Sequence.from_fasta(fasta_string)
+            Sequence(header='test', sequence='ACGT', \
+alphabet=Alphabet(name='DNA', members='-?ACGNT'))
+
+        Arguments:
+            string (str)
+
+        Returns:
+            Sequence
+        """
+        lines = string.strip().split('\n')
+        header = lines[0][1:]
+        sequence = ''.join(lines[1:])
+        return cls(header, sequence)
+
+    def to_fasta(self) -> str:
+        """Make fasta formatted sequence entry
+
+        Returns:
+            str: sequence in fasta format
+        """
+        return f'>{self.header}\n{self.sequence}'
+
+
+class SequenceReader:
+    def __init__(
+        self,
+        string: str = None,
+        filename: str = None,
+        filetype: str = None
+    ) -> None:
+        """Iterator over fasta/json formatted sequence strings
+
+        Args:
+            string (str): fasta/json formatted string
+            filename (str): fasta/json file name
+            filetype (str): fasta or json
+
+        Examples:
+            >>> fasta_string = '>1\\nACGC\\n>2\\nTGTGTA\\n'
+            >>> fasta_reader = SequenceReader(string=fasta_string, \
+filetype='fasta')
+            >>> next(fasta_reader)
+            Sequence(header='1', sequence='ACGC', \
+alphabet=Alphabet(name='DNA', members='-?ACGNT'))
+        """
+        assert bool(string) ^ bool(filename), \
+            'Must specify exactly one of string or filename'  # exclusive OR
+        if filename:
+            with open(filename, 'r') as filehandle:
+                string = filehandle.read().strip()
+
+        self.string = string
+
+        if filetype == 'fasta':
+            self._iter = self._fasta_iter
+        elif filetype == 'json':
+            self._iter = self._json_iter
+        else:
+            raise ValueError(f'filetype "{filetype}" is not supported')
+
+    def __iter__(self) -> Iterable[Sequence]:
+        """Iterate over header,sequence tuples
+
+        Returns:
+            Iterable[Sequence]: [description]
+
+        Yields:
+            Iterable[Sequence]: [description]
+        """
+        try:
+            yield from self._iter()
+        except StopIteration:
+            return
+
+    def __next__(self) -> Sequence:
+        """Next header and sequence in the iterator
+
+        Returns:
+            Tuple[str, str]: [description]
+        """
+        return next(self._iter())
+
+    def _fasta_iter(self) -> Iterable[Sequence]:
+        fasta_iter = (
+            x for _, x in groupby(
+                self.string.strip().split('\n'),
+                lambda line: line[:1] == '>'
+            )
+        )
+        for header in fasta_iter:
+            header = next(header)[1:].strip()
+            seq = ''.join(s.strip() for s in next(fasta_iter))
+            yield Sequence(header, seq)
+
+    def _json_iter(self) -> Iterable[Sequence]:
+        for entry in json.loads(self.string):
+            yield Sequence(entry['header'], entry['sequence'])
+
+
+class SequenceCollection(metaclass=ABCMeta):
+    """
+    (Partially) Abstract Base Class for sequence collections.
+    Classes extending from this baseclass should override
+    `__setitem__`, `__getitem__`, `__delitem__`, `headers`, and `n_seqs`.
+
+    If the above methods are implemented, this automatically enables the
+    following methods: `from_fasta`, `to_fasta`, `from_json`, `to_json`.
+
+    Args:
+        sequences (Optional[Iterable[Tuple[str, str]]], optional):
+            Iterable of (header, sequence) tuples. Defaults to None.
+        sequence_annotation (Optional[SequenceAnnotation]):
+                picea SequenceAnnotation object. Defaults to None.
+
+    Raises:
+        NotImplementedError: Abstract Base Class can not be initialized
+            and serves as a template only
+    """
+    @abstractmethod
+    def __init__(
+        self,
+        sequences: Optional[Iterable[Sequence]] = None,
+        sequence_annotation: Optional['SequenceAnnotation'] = None
+    ) -> None:
+        raise NotImplementedError('Not implemented in base class')
+
+    @abstractmethod
+    def __setitem__(self, header: str, seq: str) -> None:
+        raise NotImplementedError()
+
+    @abstractmethod
+    def __getitem__(self, header: str) -> Sequence:
+        raise NotImplementedError()
+
+    @abstractmethod
+    def __delitem__(self, header: str) -> None:
+        raise NotImplementedError()
+
+    def __iter__(self) -> Iterable[Sequence]:
+        for header in self.headers:
+            yield self[header]
+
+    def __next__(self) -> Sequence:
+        header = next(self.headers)
+        return self[header]
+
+    @abstractproperty
+    def headers(self) -> List[str]:
+        """List of sequences headers.
+        Overridden in subclasses.
+
+        Raises:
+            NotImplementedError
+
+        Returns:
+            List[str]: List of sequence headers
+        """
+        raise NotImplementedError()
+
+    @property
+    def sequences(self) -> List[str]:
+        """List of sequences without headers
+
+        Returns:
+            List[str]: list of sequences
+        """
+        return [self[header].sequence for header in self.headers]
+
+    @abstractproperty
+    def n_seqs(self) -> int:
+        """Return the number of sequences in the collection.
+        Overridden in subclasses
+
+        Raises:
+            NotImplementedError
+
+        Returns:
+            int: number of sequences
+        """
+        raise NotImplementedError()
+
+    @classmethod
+    def from_fasta(
+        cls,
+        filename: str = None,
+        string: str = None,
+    ) -> 'SequenceCollection':
+        """Parse a fasta formatted string into a SequenceCollection object
+
+        Keyword Arguments:
+            filename {String} -- filename string (default: {None})
+            string {String} -- fasta formatted string (default: {None})
+
+        Returns:
+            SequenceCollection -- SequenceCollection instance
+        """
+        sequencecollection = cls()
+
+        for seq in SequenceReader(
+            string=string, filename=filename, filetype='fasta'
+        ):
+            sequencecollection[seq.header] = seq.sequence
+        return sequencecollection
+
+    def to_fasta(self) -> str:
+        """Get a fasta-formatted string of the sequence collection
+
+        Returns:
+            str: Multi-line fasta-formatted string
+        """
+        return '\n'.join([seq.to_fasta() for seq in self])
+
+    @classmethod
+    def from_json(
+        cls,
+        filename: Optional[str] = None,
+        string: Optional[str] = None
+    ) -> 'SequenceCollection':
+        """[summary]
+
+        Keyword Arguments:
+            string {String} -- JSON formatted string
+
+        Returns:
+            SequenceCollection -- SequenceCollection instance
+        """
+        sequencecollection = cls()
+
+        for seq in SequenceReader(
+            string=string, filename=filename, filetype='json'
+        ):
+            sequencecollection[seq.header] = seq.sequence
+
+        return sequencecollection
+
+    def to_json(self, indent: Optional[int] = None) -> str:
+        """[summary]
+
+        Returns:
+            str: [description]
+        """
+        gene_dicts = [seq.to_dict() for seq in self]
+        return json.dumps(gene_dicts, indent=indent)
+
+
+class SequenceList(SequenceCollection):
+    """
+    A container for multiple (unaligned) DNA or amino acid sequences
+    """
+    def __init__(
+        self: 'SequenceCollection',
+        sequences: Iterable[Tuple[str, str]] = None,
+        sequence_annotation: 'SequenceAnnotation' = None
+    ):
+        self._collection = dict()
+        if sequences:
+            for header, sequence in sequences:
+                self[header] = sequence
+        self.sequence_annotation = sequence_annotation
+
+    def __setitem__(self, header: str, seq: str) -> None:
+        if header in self.headers:
+            warn(f'Turning duplicate header "{header}" into unique header')
+            new_header = header
+            modifier = 0
+            while new_header in self.headers:
+                modifier += 1
+                new_header = f'{header}_{modifier}'
+            header = new_header
+        self._collection[header] = seq
+
+    def __getitem__(self, header: str) -> Sequence:
+        sequence = self._collection[header]
+        return Sequence(header, sequence)
+
+    def __delitem__(self, header: str) -> None:
+        del self._collection[header]
+
+    @property
+    def headers(self) -> List[str]:
+        return list(self._collection.keys())
+
+    @property
+    def n_seqs(self) -> int:
+        return len(self._collection.keys())
+
+    def align(
+        self,
+        method: str = 'mafft',
+        method_kwargs: Dict[str, str] = dict()
+    ):
+        """[summary]
+
+        Args:
+            method (str, optional): [description]. Defaults to 'mafft'.
+            method_kwargs (Dict[str, str], optional): [description]. \
+                Defaults to dict().
+
+        Returns:
+            [type]: [description]
+        """
+        fasta = self.to_fasta()
+        command = [method, *chain(*method_kwargs.items()), '-']
+        process = Popen(
+            command,
+            stdin=PIPE,
+            stdout=PIPE,
+            stderr=PIPE
+        )
+        stdout, stderr = process.communicate(input=fasta.encode())
+        aligned_fasta = stdout.decode().strip()
+        return MultipleSequenceAlignment.from_fasta(string=aligned_fasta)
+
+
+class MultipleSequenceAlignment(SequenceCollection):
+    def __init__(
+        self,
+        sequences: Optional[Iterable[Sequence]] = None,
+        sequence_annotation: Optional['SequenceAnnotation'] = None
+    ) -> None:
+        """
+        A container for multiple aligned DNA or amino acid sequences
+        """
+        self._collection = np.empty((0, 0), dtype='uint8')
+        self._header_idx = dict()
+        if sequences:
+            for seq in sequences:
+                self[seq.header] = seq.sequence
+        # if sequence_annotation:
+        #     sequence_annotation.sequence_collection = self
+        self.sequence_annotation = sequence_annotation
+
+    def __setitem__(self, header: str, seq: str) -> None:
+        seq = seq.encode()
+        if header in self._header_idx:
+            warn(f'Turning duplicate header "{header}" into unique header')
+            new_header = header
+            modifier = 0
+            while new_header in self._header_idx:
+                modifier += 1
+                new_header = f'{header}_{modifier}'
+            header = new_header
+        n_seq, n_char = self._collection.shape
+        if n_seq == 0:
+            self._collection = np.array([[*seq]], dtype='uint8')
+        else:
+            len_diff = len(seq) - n_char
+
+            filler1 = np.array([[*b'-'] * len_diff], dtype='uint8')
+            arr = np.hstack((
+                self._collection,
+                np.repeat(filler1, n_seq, axis=0)
+            ))
+
+            filler2 = np.array([*b'-'] * -len_diff, dtype='uint8')
+            new_row = np.array([[*seq, *filler2]], dtype='uint8')
+
+            arr = np.vstack((arr, new_row))
+            self._collection = arr
+        self._header_idx[header] = n_seq
+
+    def __getitem__(self, header: str) -> Sequence:
+        idx = self._header_idx[header]
+        n_chars = self._collection.shape[1]
+        sequence = self._collection[idx] \
+            .view(f'S{n_chars}')[0] \
+            .decode()
+        return Sequence(header, sequence)
+
+    def __delitem__(self, header: str) -> None:
+        """WIP!
+
+        Args:
+            header (str): [description]
+        """
+        idx = self._header_idx[header]
+        self._collection = np.delete(self._collection, idx, axis=0)
+        # del
+
+    @property
+    def headers(self) -> List[str]:
+        return list(self._header_idx.keys())
+
+    @property
+    def n_seqs(self) -> int:
+        return self._collection.shape[0]
+
+    @property
+    def n_chars(self) -> int:
+        return self._collection.shape[1]
+
+    @property
+    def shape(self) -> int:
+        return self._collection.shape
+
+
 def quote_gff3(attribute_value: str) -> str:
     '''pattern, repl = ENCODE_SPECIAL_CHARACTERS[0]
     quoted_value = re.sub(pattern, repl, attribute_value)
