@@ -3,7 +3,7 @@ from unittest import TestCase
 from picea import Tree
 
 
-class SequenceTests(TestCase):
+class TreeTests(TestCase):
     def setUp(self):
         self.newick = '(((a,b),(c,d)),e);'
 
@@ -15,9 +15,14 @@ class SequenceTests(TestCase):
 
     def test_input_output(self):
         tree = Tree.from_newick(self.newick)
-        assert self.newick == tree.to_newick(branch_lengths=False)
+        self.assertEqual(self.newick, tree.to_newick(branch_lengths=False))
 
     def test_root(self):
         tree = Tree.from_newick(self.newick)
         deep_node = tree.loc['a']
-        assert deep_node.root == tree
+        self.assertEqual(deep_node.root, tree)
+
+    def test_quoted_fasttree_newick(self):
+        Tree.from_newick(
+            filename='./tests/data/fasttree.quoted_labels.newick'
+        )
